@@ -38,7 +38,7 @@ class CustomGS extends CMSModule
 	
 	function GetVersion()
 	{
-		return '1.3';
+		return '1.6';
 	}
 	
 	function MinimumCMSVersion()
@@ -88,7 +88,7 @@ class CustomGS extends CMSModule
 
 	function VisibleToAdminUser() 
 	{
-		return $this->CheckPermission('Custom Global Settings - Manage') || $this->CheckPermission('Custom Global Settings - Use');
+		return ($this->CheckPermission('Custom Global Settings - Manage') || $this->CheckPermission('Custom Global Settings - Use'));
 	}
 
 	function GetDependencies()
@@ -132,10 +132,12 @@ class CustomGS extends CMSModule
 	function GetHeaderHTML()
 	{
 		$tmpl = <<<EOT
-<link rel="stylesheet" type="text/css" href="../modules/CustomGS/lib/jquery/jquery-ui.smoothness.css" media="screen" /> <!-- smoothness/jquery-ui-1.8.12.custom.css -->
-{literal}
+<link rel="stylesheet" type="text/css" href="../modules/CustomGS/lib/jquery/jquery-ui.smoothness.css" media="all" /> <!-- smoothness/jquery-ui-1.8.12.custom.css -->
+<link rel="stylesheet" type="text/css" href="../modules/CustomGS/lib/jquery/colorpicker.css" media="all">
+<script type="text/javascript" src="../modules/CustomGS/lib/jquery/jquery.tablednd.js"></script>
 <style type="text/css">
 	.cms_label { margin-right:12px; }
+	.smartyvar { padding:0 3px; cursor:text; }
 	/* css for timepicker */
 	.ui-timepicker-div .ui-widget-header { margin-bottom: 8px; }
 	.ui-timepicker-div dl { text-align: left; }
@@ -143,10 +145,33 @@ class CustomGS extends CMSModule
 	.ui-timepicker-div dl dd { margin: 0 10px 10px 65px; }
 	.ui-timepicker-div td { font-size: 90%; }
 	.ui-tpicker-grid-label { background: none; border: none; margin: 0; padding: 0; }
+
+	.cgs_fieldset {
+			margin-top:10px;
+			padding-top:0;
+			padding-bottom:10px;
+	}
+
+	.cgs_collapsible {
+			cursor: pointer;
+	}
+
+	.collapse-open span {
+			display:inline-block;
+			width:14px;
+			height:14px;
+			background:url(../modules/CustomGS/lib/jquery/images/ui-icons_454545_256x240.png) -18px -192px no-repeat;
+	}
+
+	.collapse-close span {
+			display:inline-block;
+			width:14px;
+			height:14px;
+			background:url(../modules/CustomGS/lib/jquery/images/ui-icons_454545_256x240.png) -2px -192px no-repeat;
+	}
 </style>
-{/literal}
 EOT;
-		return $this->ProcessTemplateFromData($tmpl);
+		return $tmpl;
 	}
 
 	/**
@@ -172,6 +197,51 @@ EOT;
 		return $row;
 	}
 
+	/**
+	* Method to get parameters of fields
+	*
+	* @final
+	* @access public
+	* @return array()
+	*/
+	function GetFields()
+	{
+		$userid = get_userid();
+		$userops = cmsms()->GetUserOperations();
+		$adminperm = $userops->UserInGroup($userid, 1); // is admin
+		
+		$fields = array();
+
+		$db = cmsms()->GetDB();
+		$query = "SELECT * FROM ".cms_db_prefix()."module_customgs ORDER BY sortorder ASC";
+		$result = $db->Execute($query);
+		if ( $result && $result->RecordCount() > 0 )
+		{
+			while ( $row=$result->FetchRow() )
+			{
+				// check editor permissions
+				$editperm = FALSE;
+				if ( !$adminperm && !empty($row['editors']) )
+				{
+					$editors = explode(';', $row['editors']);
+					foreach ($editors as $editor)
+					{
+						$editperm = $editperm || $userops->UserInGroup($userid, $editor);
+					}
+				}
+				else
+				{
+					$editperm = TRUE;
+				}
+				if ( $editperm )
+				{
+					$fields[$row['fieldid']] = $row;
+				}
+			}
+		}
+		return $fields;
+	}
+
 	/**
 	* Method to get all settings
 	*
@@ -182,7 +252,8 @@ EOT;
 	function GetSettings($parseSmarty = true)
 	{
 		$fields = array();
-
+		
+		$smarty = cmsms()->GetSmarty();
 		$db = cmsms()->GetDB();
 		$query = "SELECT * FROM " . cms_db_prefix() . "module_customgs";
 		$result = $db->Execute($query);
@@ -190,16 +261,31 @@ EOT;
 		{
 			while ( $row=$result->FetchRow() )
 			{
-				$alias = str_replace('__', '_', str_replace('-', '_', munge_string_to_url($row['name'])));
-				if ( $parseSmarty && ($row['type'] == 'textarea' || $row['type'] == 'wysiwyg') && $row['properties'] )
+				if ( $row['type'] != 'fieldsetstart' && $row['type'] != 'fieldsetend' )
 				{
-					$fields[$alias] = $this->ProcessTemplateFromData($row['value']);
+					$alias = str_replace('__', '_', str_replace('-', '_', munge_string_to_url($row['name'])));
+					if ( $row['type'] == 'colorpicker' )
+					{
+						$fields[$alias] = "#".$row['value'];
+					}
+					elseif ( $parseSmarty && ($row['type'] == 'textarea' || $row['type'] == 'wysiwyg') && $row['properties'] )
+					{
+						global $CMS_VERSION;
+						if ( $CMS_VERSION >= '1.11' )
+						{
+							$fields[$alias] = $smarty->fetch('string:'.$row['value']);
+						}
+						else
+						{
+							$fields[$alias] = $this->ProcessTemplateFromData($row['value']);
+						}
+					}
+					else
+					{
+						$fields[$alias] = $row['value'];
+					}
+					$fields[$row['fieldid']] = $fields[$alias];
 				}
-				else
-				{
-					$fields[$alias] = $row['value'];
-				}
-				$fields[$row['fieldid']] = $fields[$alias];
 			}
 		}
 		return $fields;
@@ -214,7 +300,7 @@ EOT;
 	*/
 	function ClearStylesheetCache()
 	{
-		foreach (glob("../tmp/cache/stylesheet_combined_*.css") as $filename) {
+		foreach (glob("../../tmp/cache/stylesheet_combined_*.css") as $filename) {
 			@unlink($filename);
 		}
 	}
