@@ -83,13 +83,26 @@ switch ($params['mode'])
 				{
 					$params['properties'] = '';
 				}
+				elseif ( $params['type'] == 'fieldsetstart' )
+				{
+					$params['type'] = 'fieldsetstart';
+					$params['properties'] = '';
+				}
 				$params['clearcache'] = isset($params['clearcache']);
+				$editors = empty($params['editors']) ? '' : implode(';', $params['editors']);
+				
 				// save fielddefinition
-				$query = "INSERT INTO ".cms_db_prefix()."module_customgs (name, help, type, properties, clearcache, sortorder) VALUES (?,?,?,?,?,?)";
-				$result = $db->Execute($query, array($params['name'], $params['help'], $params['type'], $params['properties'], $params['clearcache'], $field['maxsortorder'] + 1));
+				$query = "INSERT INTO ".cms_db_prefix()."module_customgs (name, help, type, properties, clearcache, sortorder, editors) VALUES (?,?,?,?,?,?,?)";
+				$result = $db->Execute($query, array($params['name'], $params['help'], $params['type'], $params['properties'], $params['clearcache'], $field['maxsortorder'] + 1, $editors));
 			}
 			if( isset($result) && $result )
 			{
+				// add also fieldsetend if fieldsetstart was added
+				if ( $params['type'] == 'fieldsetstart' )
+				{
+					$result = $db->Execute($query, array($params['name'], '', 'fieldsetend', '', $params['clearcache'], $field['maxsortorder'] + 2, $editors));
+				}
+
 				// Put mention into the admin log
 				audit($db->Insert_ID(), 'Custom Global Settings - Fielddefinition', 'Added: ' . $params['name']);
 				$params = array('tab_message'=> 'fielddefadded', 'active_tab' => 'fielddefs');
@@ -101,7 +114,7 @@ switch ($params['mode'])
 
 			$this->Redirect($id, 'defaultadmin', '', $params);
 		}
-		$field = array('name' => '', 'help' => '', 'type' => '', 'maxlength' => '', 'properties' => '', 'parsesmarty' => '', 'clearcache' => 0);
+		$field = array('name' => '', 'help' => '', 'type' => '', 'maxlength' => '', 'properties' => '', 'parsesmarty' => '', 'clearcache' => 0, 'editors' => '');
 		$smarty->assign('title',lang('add'));
 		$smarty->assign('hidden', $this->CreateInputHidden($id, 'mode', 'add'));
 		break;
@@ -114,23 +127,34 @@ switch ($params['mode'])
 			$this->Redirect($id,'defaultadmin','',$params);
 			return;
 		}
-    $query = "SELECT name, sortorder FROM ".cms_db_prefix()."module_customgs WHERE fieldid = ?";
-		$result = $db->Execute($query, array($params['fieldid']));
-		if( !$result || $result->RecordCount() == 0 )
+		
+		$field = $this->GetField($params['fieldid']);
+		if( $field === FALSE )
 		{
 			$params = array('module_error'=> 'fielddefupdatefailed', 'active_tab' => 'fielddefs');
 			$this->Redirect($id, 'defaultadmin', '', $params);
 		}
-		$row = $result->FetchRow();
-
 		$query = "DELETE FROM " . cms_db_prefix() . "module_customgs WHERE fieldid = ?";
 		$db->Execute($query, array($params['fieldid']));
 		// Put mention into the admin log
-		audit($params['fieldid'], 'Custom Global Settings - Fielddefinition', 'Deleted: ' . $row['name']);
+		audit($params['fieldid'], 'Custom Global Settings - Fielddefinition', 'Deleted: ' . $field['name']);
 
 		// update the sortorder
 		$query = "UPDATE " . cms_db_prefix() . "module_customgs SET sortorder = sortorder - 1 WHERE sortorder > ?";
-		$result = $db->Execute($query, array($row['sortorder']));
+		$result = $db->Execute($query, array($field['sortorder']));
+		
+		// delete fieldsetend
+		if ( $field['type'] == 'fieldsetstart' )
+		{
+			$field2 = $this->GetField($field['name']);
+			if( $field2 !== FALSE )
+			{
+				$query = "DELETE FROM " . cms_db_prefix() . "module_customgs WHERE fieldid = ?";
+				$db->Execute($query, array($field2['fieldid']));
+				$query = "UPDATE " . cms_db_prefix() . "module_customgs SET sortorder = sortorder - 1 WHERE sortorder > ?";
+				$result = $db->Execute($query, array($field2['sortorder']));
+			}
+		}
 
 		$params = array('tab_message'=> 'fielddefsupdated', 'active_tab' => 'fielddefs');
 		$this->Redirect($id, 'defaultadmin', '', $params);
@@ -145,12 +169,14 @@ switch ($params['mode'])
 			return;
 		}
 
+		$field = $this->GetField($params['fieldid']);
+
 		if( $_SERVER['REQUEST_METHOD'] == 'POST' )
 		{
 			// check if name is empty
 			if ( empty($params['name']) ) $params['name'] = $params['type'] . "1";
 			// check if name already exists
-			$checkfieldname = $this->GetField($params['name']);
+			$checkfieldname = $field['type'] == 'fieldsetstart' ? FALSE : $this->GetField($params['name']);
 			While ( $checkfieldname !== FALSE && $params['fieldid'] != $checkfieldname['fieldid'] )
 			{
 				if ( is_numeric(substr($params['name'], -1)) )
@@ -177,10 +203,16 @@ switch ($params['mode'])
 				$params['properties'] = '';
 			}
 			$params['clearcache'] = isset($params['clearcache']);
+			$editors = empty($params['editors']) ? '' : implode(';', $params['editors']);
 
 			// save fielddefinition
-			$query = "UPDATE " . cms_db_prefix() . "module_customgs SET name = ?, help = ?, type = ?, properties = ?, clearcache = ? WHERE fieldid = ?";
-			$result = $db->Execute($query, array($params['name'], $params['help'], $params['type'], $params['properties'], $params['clearcache'], $params['fieldid']));
+			$query = "UPDATE " . cms_db_prefix() . "module_customgs SET name = ?, help = ?, type = ?, properties = ?, clearcache = ?, editors = ? WHERE fieldid = ?";
+			$result = $db->Execute($query, array($params['name'], $params['help'], $params['type'], $params['properties'], $params['clearcache'], $editors, $params['fieldid']));
+			if ( $field['type'] == 'fieldsetstart' )
+			{
+				$query = "UPDATE " . cms_db_prefix() . "module_customgs SET name = ?, editors = ? WHERE name = ? AND fieldid <> ?";
+				$result = $db->Execute($query, array($params['name'], $editors, $field['name'], $params['fieldid']));
+			}
 
 			// Put mention into the admin log
 			audit($params['fieldid'], 'Custom Global Settings - Fielddefinition', 'Edited: ' . $params['name']);
@@ -188,7 +220,6 @@ switch ($params['mode'])
 			$params = array('tab_message'=> 'fielddefsupdated', 'active_tab' => 'fielddefs');
 			$this->Redirect($id, 'defaultadmin', '', $params);
 		}
-		$field = $this->GetField($params['fieldid']);
 
 		$smarty->assign('title',lang('edit'));
 		$smarty->assign('hidden', $this->CreateInputHidden($id, 'fieldid', $params['fieldid']) .
@@ -198,17 +229,15 @@ switch ($params['mode'])
 
 	case 'moveup':
 	case 'movedown':
-		$query = "SELECT * FROM " . cms_db_prefix() . "module_customgs WHERE fieldid = ?";
-		$result = $db->Execute($query, array($params['fieldid']));
-		if( !$result || $result->RecordCount() == 0 )
+		$field = $this->GetField($params['fieldid']);
+		if( $field === FALSE )		 
 		{
 			$params = array('module_error'=> 'typeupdatefailed', 'active_tab' => 'types');
 			$this->Redirect($id, 'defaultadmin', '', $params);
 		}
-		$row = $result->FetchRow();
 
 		$query = "UPDATE " . cms_db_prefix() . "module_customgs SET sortorder = " . ($params['mode'] == 'moveup' ? 'sortorder + 1' : 'sortorder - 1') . " WHERE sortorder = ?";
-		$result = $db->Execute($query, array($params['mode'] == 'moveup' ? $row['sortorder'] - 1 : $row['sortorder'] + 1));
+		$result = $db->Execute($query, array($params['mode'] == 'moveup' ? $field['sortorder'] - 1 : $field['sortorder'] + 1));
 
 		$query = "UPDATE " . cms_db_prefix() . "module_customgs SET sortorder = " . ($params['mode'] == 'moveup' ? 'sortorder - 1' : 'sortorder + 1') . " WHERE fieldid = ?";
 		$result = $db->Execute($query, array($params['fieldid']));
@@ -217,6 +246,21 @@ switch ($params['mode'])
 		$this->Redirect($id, 'defaultadmin', '', $params);
 		break;
 
+		
+	case 'sort':
+		if ( !empty($params['sortseq']) )
+		{
+			$sortseq = str_replace('i', '', $params['sortseq']);
+			$sortentries = explode(',', $sortseq);
+			foreach ( $sortentries as $key => $fieldid )
+			{
+				$query = "UPDATE " . cms_db_prefix() . "module_customgs SET sortorder = ? WHERE fieldid = ?";
+				$db->Execute($query, array($key + 1, $fieldid));
+			}
+		}
+		exit();
+		break;
+
 }
 
 
@@ -230,36 +274,62 @@ $typelist = array(
 	$this->Lang('timepicker') => 'timepicker',
 	$this->Lang('textarea') => 'textarea',
 	$this->Lang('wysiwyg') => 'wysiwyg',
+	$this->Lang('colorpicker') => 'colorpicker',
+	$this->Lang('fieldsetstart') => 'fieldsetstart',
 	$this->Lang('button') => 'button');
 
-$smarty->assign('prompt_name',lang('name'));
-$smarty->assign('name', $this->CreateInputText( $id, 'name', $field['name'], 40 ));
+$disabled = $field['type'] == 'fieldsetstart' ? ' disabled="disabled"' : '';
+
+$gbfp = cms_utils::get_module('GBFilePicker');
+if( $gbfp )
+{
+	$gbfp_name = $gbfp->GetFriendlyName();
+	$typelist[$gbfp_name] = 'gbfilepicker';
+}
+
+
+
+$smarty->assign('prompt_name', lang('name'));
+$smarty->assign('name', $this->CreateInputText($id, 'name', $field['name'], 40 ));
 
 $smarty->assign('prompt_type', lang('type'));
-$smarty->assign('type', $this->CreateInputDropdown($id, 'type', $typelist, -1, $field['type'], 'id="fieldtype"'));
+$smarty->assign('type', $this->CreateInputDropdown($id, 'type' . ($disabled ? '_' : ''), $typelist, -1, $field['type'], 'id="fieldtype"' . $disabled) . ($disabled ? $this->CreateInputHidden($id, 'type', $field['type']) : ''));
 
-$smarty->assign('prompt_maxlength',$this->Lang('maxlength'));
-$smarty->assign('maxlength', $this->CreateInputText( $id, 'maxlength', $field['type'] == 'textfield' ? $field['properties'] : '', 5, 5));
+$smarty->assign('prompt_maxlength', $this->Lang('maxlength'));
+$smarty->assign('maxlength', $this->CreateInputText($id, 'maxlength', $field['type'] == 'textfield' ? $field['properties'] : '', 5, 5));
 
 $smarty->assign('prompt_properties', $this->Lang('properties'));
 $smarty->assign('help_properties', $this->Lang('properties_help1'));
 $smarty->assign('properties', $this->CreateTextArea(FALSE, $id, $field['type'] == 'pulldown' || $field['type'] == 'radiobuttons' ? $field['properties'] : '', 'properties', '', '' , '' , '', 20, 6, '', '', 'style="width:20em; height:6em;"'));
 
-$smarty->assign('prompt_parsesmarty',$this->Lang('parsesmarty'));
+$smarty->assign('prompt_parsesmarty', $this->Lang('parsesmarty'));
 $smarty->assign('parsesmarty', $this->CreateInputCheckbox($id, 'parsesmarty', '1', $field['type'] == 'textarea' || $field['type'] == 'wysiwyg' ? $field['properties'] : ''));
 
 $smarty->assign('prompt_help', lang('help'));
-$smarty->assign('help', $this->CreateInputText( $id, 'help', $field['help'], 80 ));
+$smarty->assign('help', $this->CreateInputText($id, 'help', $field['help'], 80 ));
 
 $smarty->assign('prompt_clearcache', $this->Lang('clearstylesheetcache'));
 $smarty->assign('help_clearcache', $this->Lang('clearstylesheetcache_help'));
 $smarty->assign('clearcache', $this->CreateInputCheckbox($id, 'clearcache', '1', $field['clearcache']));
 
-$smarty->assign('submit',$this->CreateInputSubmit ($id, 'submitbutton', lang('submit')));
-$smarty->assign('cancel',$this->CreateInputSubmit ($id, 'cancel', lang('cancel')));
+$editorslist = array();
+$disabled = '';
+$groupops = $gCms->GetGroupOperations();
+$groups = $groupops->LoadGroups();
+foreach ($groups as $onegroup)
+{
+	//if( $onegroup->id == 1 ) continue;
+	$editorslist[lang('group') . ': ' . $onegroup->name] = $onegroup->id;
+}
+$selectededitors = explode(';', $field['editors']);
+$smarty->assign('prompt_editors', lang('grouppermissions'));
+$smarty->assign('editors', $this->CreateInputSelectList($id, 'editors[]', $editorslist, $selectededitors, 4, $disabled));
 
-$smarty->assign('formstart', $this->CreateFormStart ($id, 'editfielddef', $returnid));
-$smarty->assign('formend',$this->CreateFormEnd());
+$smarty->assign('submit', $this->CreateInputSubmit($id, 'submitbutton', lang('submit')));
+$smarty->assign('cancel', $this->CreateInputSubmit($id, 'cancel', lang('cancel')));
+
+$smarty->assign('formstart', $this->CreateFormStart($id, 'editfielddef', $returnid));
+$smarty->assign('formend', $this->CreateFormEnd());
 
 echo $this->ProcessTemplate('editfielddef.tpl');
 
