@@ -13,7 +13,6 @@ $lang['now'] = 'now';
 $lang['title_general'] = 'General';
 $lang['choosetime'] = 'Choose time';
 $lang['time'] = 'time';
-$lang[''] = '';
 
 
 /**
@@ -28,8 +27,12 @@ $lang['radiobuttons'] = 'Radiobutton group';
 $lang['datepicker'] = 'Datepicker';
 $lang['datetimepicker'] = 'DateTimepicker';
 $lang['timepicker'] = 'Timepicker';
+$lang['colorpicker'] = 'Colorpicker';
 $lang['textarea'] = 'Text Area';
 $lang['wysiwyg'] = 'WYSIWYG';
+// $lang['fieldset'] = 'Fieldgroup';
+$lang['fieldsetstart'] = 'Fieldgroup start';
+$lang['fieldsetend'] = 'Fieldgroup end';
 $lang['button'] = 'Button';
 $lang['maxlength'] = 'Maximum Length';
 $lang['properties'] = 'Properties';
@@ -48,7 +51,8 @@ $lang['title_custom_modulename'] = 'Custom Modulename';
 $lang['help_custom_modulename'] = 'You can change the Modulename here as you wish. It will be used as the title on the module admin pages and as menu text.';
 
 $lang['title_admin_section'] = 'Admin Section';
-$lang['help_admin_section'] = 'Choose the Admin Section (or top-level Admin Menu) this module belongs to.';
+$lang['help_admin_section'] = 'Choose the Admin Section (or top-level Admin Menu) this module belongs to. <b>Note</b>: Users with Editor permissions don\'t have access to the Site Admin section!';
+
 
 /**
  * Saving
