@@ -16,8 +16,11 @@ $lang['radiobuttons'] = 'Radioknopf-Gruppe';
 $lang['datepicker'] = 'Datumsauswahl';
 $lang['datetimepicker'] = 'Datums-Zeitauswahl';
 $lang['timepicker'] = 'Zeitauswahl';
+$lang['colorpicker'] = 'Farbauswahl';
 $lang['textarea'] = 'Textbereich';
 $lang['wysiwyg'] = 'Wysiwyg';
+$lang['fieldsetstart'] = 'Feldergruppe Anfang';
+$lang['fieldsetend'] = 'Feldergruppe Ende';
 $lang['button'] = 'Taste';
 $lang['maxlength'] = 'Maximale L&auml;nge';
 $lang['properties'] = 'Eigenschaften';
@@ -25,12 +28,13 @@ $lang['properties_help1'] = 'Geben Sie die Auswahl-Werte ein, jeweils in einer n
 $lang['parsesmarty'] = 'Daten durch Smarty verarbeiten';
 $lang['clearstylesheetcache'] = 'Zwischengespeicherten Stylesheets l&ouml;schen';
 $lang['clearstylesheetcache_help'] = 'Automatisch zwischengespeicherten Stylesheets l&ouml;schen nach &Auml;nderung dieser Einstellung. VORSICHT BEI DER VERWENDUNG!';
+$lang['editors'] = 'Bearbeiter';
 $lang['fielddefadded'] = 'Die Feld-Definition wurde hinzugef&uuml;gt';
 $lang['fielddefsupdated'] = 'Die Liste der Feld-Definitionen wurde aktualisiert';
-$lang['title_custom_modulename'] = 'Benutzerdefinierter Modulname';
+$lang['title_custom_modulename'] = 'Benutzerdefinierte Modulname';
 $lang['help_custom_modulename'] = 'Sie k&ouml;nnen den Modulnamen hier &auml;ndern. Es wird als Titel der Modul Admin-Seiten und als Men&uuml; Text verwendet.';
 $lang['title_admin_section'] = 'Admin-Bereich';
-$lang['help_admin_section'] = 'W&auml;hlen Sie den Admin-Bereich (von Top-Level Admin Menu), wo dieses Modul zu geh&ouml;rt. <strong>Hinweis:</strong> Leeren Sie denn Zwischenspeicher der Seite, um das Ergebnis zu sehen';
+$lang['help_admin_section'] = 'W&auml;hlen Sie den Admin-Bereich (von Top-Level Admin Menu), wo dieses Modul zu geh&ouml;rt. <strong>Hinweis:</strong> Benutzer mit Editor-Berechtigungen haben keinen Zugriff auf den Admin-Bereich!';
 $lang['settingssaved'] = 'Die Einstellungen wurden erfolgreich gespeichert!';
 $lang['event_info_OnSettingChange'] = 'Ausf&uuml;hren, nachdem die &Auml;nderungen des Einstellungen gespeichert wurden.';
 $lang['event_help_OnSettingChange'] = '<p>Ausf&uuml;hren, nachdem die &Auml;nderungen der Einstellungen gespeichert wurden.</p>
@@ -42,8 +46,8 @@ $lang['event_help_OnSettingChange'] = '<p>Ausf&uuml;hren, nachdem die &Auml;nder
 <li>value</li>
 <li>clearcache</li>
 </ul>';
-$lang['utma'] = '156861353.1754265119.1344942943.1344942943.1344942943.1';
-$lang['utmz'] = '156861353.1344942943.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
-$lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.1238046435.1386149023.1386149023.1386149023.1';
 $lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1386149023.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
