@@ -49,7 +49,8 @@ $flds = "
 	properties X,
 	clearcache I,
 	sortorder I,
-	value X
+	value X,
+	editors C(255)
 ";
 
 $sqlarray = $dict->CreateTableSQL(cms_db_prefix()."module_customgs", $flds, $taboptarray);
